#ifndef NVIM_LUA_CONVERTER_H
#define NVIM_LUA_CONVERTER_H

#include <lua.h>
#include <stdbool.h>
#include <stdint.h>

#include "nvim/api/private/defs.h"
#include "nvim/eval/typval.h"
#include "nvim/func_attr.h"

#ifdef INCLUDE_GENERATED_DECLARATIONS
# include "lua/converter.h.generated.h"
#endif
#endif  // NVIM_LUA_CONVERTER_H
